PyZMP
=====
.. image:: https://travis-ci.org/asmodehn/pyzmp.svg?branch=master
    :target: https://travis-ci.org/asmodehn/pyzmp

.. image:: https://requires.io/github/asmodehn/pyzmp/requirements.svg?branch=master
     :target: https://requires.io/github/asmodehn/pyzmp/requirements/?branch=master
     :alt: Requirements Status

.. image:: https://landscape.io/github/asmodehn/pyzmp/master/landscape.svg?style=flat
   :target: https://landscape.io/github/asmodehn/pyzmp/master
   :alt: Code Health

.. image:: https://www.quantifiedcode.com/api/v1/project/6e2a3dc5e5b142e9b7db86d0dcf1be3c/badge.svg
  :target: https://www.quantifiedcode.com/app/project/6e2a3dc5e5b142e9b7db86d0dcf1be3c
  :alt: Code issues

PyZMP is a multiprocess library based on ZeroMQ.

Install
```
python setup.py develop
```

Run tests with tox
```
tox
```